@@ -1,15 +1,13 @@
 #!/bin/sh
 
+__last_exit_status=0
+
 __projectenv__sync() {
     __projectenv__off
-    source $PROJECTENV_HOME/environments/$env_name/bin/activate
     __projectenv__python $*
 
-    if [ $? ]; then
-        deactivate
+    if [ $__last_exit_status == 0 ]; then
         __projectenv__on
-    else
-        deactivate
     fi
 }
 
@@ -34,6 +32,7 @@ __projectenv__python() {
     export _PROJECTENV_OLD_PYTHONPATH=$PYTHONPATH
     export PYTHONPATH=$PROJECTENV_PATH:$PYTHONPATH
     python $PROJECTENV_PATH $*
+    __last_exit_status=$?
     export PYTHONPATH=$_PROJECTENV_OLD_PYTHONPATH
     unset _PROJECTENV_OLD_PYTHONPATH
 }
